@@ -1,20 +1,18 @@
 import nonebot
 from nonebot.log import logger
-from nonebot.plugin import export
 
-from .browser import get_browser, shutdown_browser, get_new_page
+from .browser import get_browser, get_new_page, shutdown_browser
 from .date_source import (
-    text_to_pic,
     md_to_pic,
-    template_to_html,
     html_to_pic,
-    template_to_pic,
+    text_to_pic,
     capture_element,
+    template_to_pic,
+    template_to_html,
 )
 
 driver = nonebot.get_driver()
 config = driver.config
-export = export()
 
 
 @driver.on_startup
@@ -32,21 +30,11 @@ async def init(**kwargs):
 @driver.on_shutdown
 async def shutdown():
     await shutdown_browser()
-    logger.info("Browser Stoped.")
+    logger.info("Browser Stopped.")
 
 
 browser_init = init
 
-export.browser = init
-export.text_to_pic = text_to_pic
-export.get_new_page = get_new_page
-export.md_to_pic = md_to_pic
-export.template_to_html = template_to_html
-export.template_to_pic = template_to_pic
-export.html_to_pic = html_to_pic
-export.capture_element = capture_element
-
-
 all = [
     "browser_init",
     "text_to_pic",
